Learn R Programming

APSIMBatch (version 0.1.0.2374)

runAPSIM: Run APSIM with HPC...

Description

Run APSIM with HPC

Usage

runAPSIM(..., extra, apsim="../Apsim71/Model/apsim.exe")

Arguments

...
A list contain several simulations, or a list contain sim or RData files, See example for more detailed arguments.
apsim
The relative and absolute path to apsim.exe
extra
A data frame of extra identification for all simulation. Row number must be the same as simulation number

Value

Examples

Run this code
# Run all sim files
## Not run: files <- list.files( "./simtest", pattern = "(.*)(\.sim$)", full.names = TRUE )
## Not run: runAPSIM( files = files )
# Run Rdata file
## Not run: runAPSIM( files = "test.RData" )
# Set apsim path
## Not run: apsim <- "\"C:/Program Files/Apsim71/Model/apsim.exe\""
## Not run: runAPSIM( files = "test.RData", apsim = apsim )

Run the code above in your browser using DataLab